@@ -1,6 +1,6 @@
 import asyncio
 from dataclasses import dataclass
-from typing import List, NamedTuple, Optional
+from typing import List, Optional, Set
 
 from arq import ArqRedis
 from arq.connections import RedisSettings
@@ -13,15 +13,18 @@ from arq_admin.job import JobInfo
 from arq_admin.redis import get_redis
 
 
-class QueueStats(NamedTuple):
+@dataclass
+class QueueStats:
     name: str
     host: str
     port: int
     database: int
 
-    queued_jobs: int
-    running_jobs: int
-    deferred_jobs: int
+    queued_jobs: Optional[int] = None
+    running_jobs: Optional[int] = None
+    deferred_jobs: Optional[int] = None
+
+    error: Optional[str] = None
 
 
 @dataclass
@@ -38,9 +41,7 @@ class Queue:
 
     async def get_jobs(self, status: Optional[JobStatus] = None) -> List[JobInfo]:
         async with get_redis(self.redis_settings) as redis:
-            job_ids = set(await redis.zrangebyscore(self.name))
-            result_keys = await redis.keys(f'{result_key_prefix}*')
-            job_ids |= {key[len(result_key_prefix):] for key in result_keys}
+            job_ids = await self._get_job_ids(redis)
 
             if status:
                 job_ids_tuple = tuple(job_ids)
@@ -52,22 +53,24 @@ class Queue:
         return jobs
 
     async def get_stats(self) -> QueueStats:
-        async with get_redis(self.redis_settings) as redis:
-            job_ids = set(await redis.zrangebyscore(self.name))
-            result_keys = await redis.keys(f'{result_key_prefix}*')
-            job_ids |= {key[len(result_key_prefix):] for key in result_keys}
-
-            statuses = await asyncio.gather(*[self._get_job_status(job_id, redis) for job_id in job_ids])
-
-        return QueueStats(
+        result = QueueStats(
             name=self.name,
             host=str(self.redis_settings.host),
             port=self.redis_settings.port,
             database=self.redis_settings.database,
-            queued_jobs=len([status for status in statuses if status == JobStatus.queued]),
-            running_jobs=len([status for status in statuses if status == JobStatus.in_progress]),
-            deferred_jobs=len([status for status in statuses if status == JobStatus.deferred]),
         )
+        try:
+            async with get_redis(self.redis_settings) as redis:
+                job_ids = await self._get_job_ids(redis)
+                statuses = await asyncio.gather(*[self._get_job_status(job_id, redis) for job_id in job_ids])
+        except Exception as ex:  # noqa: B902
+            result.error = str(ex)
+        else:
+            result.queued_jobs = len([status for status in statuses if status == JobStatus.queued])
+            result.running_jobs = len([status for status in statuses if status == JobStatus.in_progress])
+            result.deferred_jobs = len([status for status in statuses if status == JobStatus.deferred])
+
+        return result
 
     async def get_job_by_id(self, job_id: str, redis: Optional[ArqRedis] = None) -> JobInfo:
         if redis is None:
@@ -80,7 +83,7 @@ class Queue:
             job_id=job_id,
             redis=redis,
             _queue_name=self.name,
-            _deserializer=settings.ARQ_DESERIALIZER,
+            _deserializer=settings.ARQ_DESERIALIZER_BY_QUEUE.get(self.name),
         )
 
         unknown_function_msg = "Can't find job"
@@ -110,6 +113,13 @@ class Queue:
             job_id=job_id,
             redis=redis,
             _queue_name=self.name,
-            _deserializer=settings.ARQ_DESERIALIZER,
+            _deserializer=settings.ARQ_DESERIALIZER_BY_QUEUE.get(self.name),
         )
         return await arq_job.status()
+
+    async def _get_job_ids(self, redis: ArqRedis) -> Set[str]:
+        raw_job_ids = set(await redis.zrangebyscore(self.name, '-inf', 'inf'))
+        result_keys = await redis.keys(f'{result_key_prefix}*')
+        raw_job_ids |= {key[len(result_key_prefix):] for key in result_keys}
+
+        return {job_id.decode('utf-8') if isinstance(job_id, bytes) else job_id for job_id in raw_job_ids}
